@@ -22,8 +22,8 @@
 #' \donttest{
 #' # Larger example
 #' data(carmel)
-#' carmel_asp = aspect(carmel)
-#' r = c(carmel, round(carmel_asp, 1), along = 3)
+#' carmel_aspect = aspect(carmel)
+#' r = c(carmel, round(carmel_aspect, 1), along = 3)
 #' r = st_set_dimensions(r, 3, values = c("input", "aspect"))
 #' plot(r, breaks = "equal", col = hcl.colors(11, "Spectral"))
 #' }
@@ -33,6 +33,11 @@
 # Apply focal filter
 aspect = function(x, na_flag = -9999) {
 
+  # Checks
+  x = check_one_attribute(x)
+  x = check_spatial_dimensions(x)
+  x = check_one_layer(x)
+
   # Make template
   template = x
 
@@ -40,7 +45,7 @@ aspect = function(x, na_flag = -9999) {
   steps = 1
 
   # To matrix
-  input = layer_to_matrix(template)  # Checks take place here
+  input = layer_to_matrix(template, check = FALSE)
   input = matrix_extend(input, n = steps)
 
   # Matrix dimensions
